@@ -194,7 +194,7 @@ be used in the set accessor (mutator) to validate new attribute values.
 
 use strict;
 use Class::Meta;
-our $VERSION = '0.64';
+our $VERSION = '0.65';
 
 sub build_attr_get {
     UNIVERSAL::can($_[0]->package, 'get_' . $_[0]->name);
@@ -352,9 +352,6 @@ Please file bug reports via L<GitHub
 Issues|http://github.com/theory/class-meta/issues/> or by sending mail to
 L<bug-Class-Meta.cpan.org|mailto:bug-Class-Meta.cpan.org>.
 
-Patches against Class::Meta are welcome. Please send bug reports to
-<bug-class-meta@rt.cpan.org>.
-
 =head1 AUTHOR
 
 David E. Wheeler <david@justatheory.com>
