@@ -68,7 +68,7 @@ without the overhead of validation checks.
 
 use strict;
 use Class::Meta::Type;
-our $VERSION = '0.64';
+our $VERSION = '0.65';
 
 sub import {
     my ($pkg, $builder) = @_;
@@ -161,9 +161,6 @@ Please file bug reports via L<GitHub
 Issues|http://github.com/theory/class-meta/issues/> or by sending mail to
 L<bug-Class-Meta.cpan.org|mailto:bug-Class-Meta.cpan.org>.
 
-Patches against Class::Meta are welcome. Please send bug reports to
-<bug-class-meta@rt.cpan.org>.
-
 =head1 AUTHOR
 
 David E. Wheeler <david@justatheory.com>
